@@ -15,3 +15,11 @@ test_that("list_engagements", {
 test_that("list_engagements", {
   expect_error(svc$list_engagements(MaxResults = 20), NA)
 })
+
+test_that("list_rotations", {
+  expect_error(svc$list_rotations(), NA)
+})
+
+test_that("list_rotations", {
+  expect_error(svc$list_rotations(MaxResults = 20), NA)
+})
